#ifndef NT2_INCLUDE_FUNCTIONS_CHEBSPEC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CHEBSPEC_HPP_INCLUDED

#include <nt2/gallery/include/functions/chebspec.hpp>

#endif
